Defined new FNAME logcode enum (only used on the client side when
[rsync/rsync.git] / rsync.h
diff --git a/rsync.h b/rsync.h
index 73cc355..1766394 100644 (file)
--- a/rsync.h
+++ b/rsync.h
        ITEM_BASIS_TYPE_FOLLOWS | ITEM_XNAME_FOLLOWS | ITEM_LOCAL_CHANGE))
 
 
-/* Log-message categories.  FLOG and FCLIENT are only used on the daemon
- * side for custom logging -- they don't get sent over the socket. */
-enum logcode { FERROR=1, FINFO=2, FLOG=3, FCLIENT=4 };
+/* Log-message categories.  Only FERROR and FINFO get sent over the socket.
+ * FLOG and FCLIENT are only used on the daemon side for custom logging,
+ * while FNAME is only used on the client side. */
+enum logcode { FERROR=1, FINFO=2, FLOG=3, FCLIENT=4, FNAME=5 };
 
 /* Messages types that are sent over the message channel.  The logcode
  * values must all be present here with identical numbers. */
 enum msgcode {
        MSG_DATA=0,     /* raw data on the multiplexed stream */
        MSG_ERROR=FERROR, MSG_INFO=FINFO, /* remote logging */
-       MSG_LOG=FLOG, MSG_FCLIENT=FCLIENT, /* sibling logging */
+       MSG_LOG=FLOG,   /* sibling logging */
        MSG_REDO=9,     /* reprocess indicated flist index */
        MSG_SUCCESS=100,/* successfully updated indicated flist index */
        MSG_DELETED=101,/* successfully deleted a file on receiving side */
@@ -586,11 +587,11 @@ struct map_struct {
 
 #define MATCHFLG_WILD          (1<<0) /* pattern has '*', '[', and/or '?' */
 #define MATCHFLG_WILD2         (1<<1) /* pattern has '**' */
-#define MATCHFLG_WILD2_PREFIX  (1<<2) /* pattern starts with '**' */
-#define MATCHFLG_ABS_PATH      (1<<3) /* path-match on absolute path */
-#define MATCHFLG_INCLUDE       (1<<4) /* this is an include, not an exclude */
-#define MATCHFLG_DIRECTORY     (1<<5) /* this matches only directories */
-#define MATCHFLG_CLEAR_LIST    (1<<6) /* this item is the "!" token */
+#define MATCHFLG_WILD2_PREFIX  (1<<2) /* pattern starts with "**" */
+#define MATCHFLG_WILD3_SUFFIX  (1<<3) /* pattern ends with "***" */
+#define MATCHFLG_ABS_PATH      (1<<4) /* path-match on absolute path */
+#define MATCHFLG_INCLUDE       (1<<5) /* this is an include, not an exclude */
+#define MATCHFLG_DIRECTORY     (1<<6) /* this matches only directories */
 #define MATCHFLG_WORD_SPLIT    (1<<7) /* split rules on whitespace */
 #define MATCHFLG_NO_INHERIT    (1<<8) /* don't inherit these rules */
 #define MATCHFLG_NO_PREFIXES   (1<<9) /* parse no prefixes from patterns */
@@ -602,6 +603,7 @@ struct map_struct {
 #define MATCHFLG_CVS_IGNORE    (1<<15)/* rule was -C or :C */
 #define MATCHFLG_SENDER_SIDE   (1<<16)/* rule applies to the sending side */
 #define MATCHFLG_RECEIVER_SIDE (1<<17)/* rule applies to the receiving side */
+#define MATCHFLG_CLEAR_LIST    (1<<18)/* this item is the "!" token */
 
 #define MATCHFLGS_FROM_CONTAINER (MATCHFLG_ABS_PATH | MATCHFLG_INCLUDE \
                                | MATCHFLG_DIRECTORY | MATCHFLG_SENDER_SIDE \
@@ -793,7 +795,7 @@ extern int errno;
 #define INITACCESSPERMS 0700
 
 /* handler for null strings in printf format */
-#define NS(s) ((s)?safe_fname(s):"<NULL>")
+#define NS(s) ((s)?(s):"<NULL>")
 
 #if !defined __GNUC__ || defined __APPLE__
 /* Apparently the OS X port of gcc gags on __attribute__.